WAMP Router for Distributed & Decentralized Microservices
=========================================================

|PyPI| |Python| |CI| |Docs| |License| |Downloads|

.. |PyPI| image:: https://img.shields.io/pypi/v/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar
.. |Python| image:: https://img.shields.io/pypi/pyversions/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar
.. |CI| image:: https://github.com/crossbario/crossbar/workflows/main/badge.svg
   :target: https://github.com/crossbario/crossbar/actions?query=workflow%3Amain
.. |Docs| image:: https://readthedocs.org/projects/crossbar/badge/?version=latest
   :target: https://crossbar.readthedocs.io/en/latest/
.. |License| image:: https://img.shields.io/pypi/l/crossbar.svg
   :target: https://github.com/crossbario/crossbar/blob/master/LICENSE
.. |Downloads| image:: https://img.shields.io/pypi/dm/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar

--------------

`Crossbar.io <https://crossbar.io>`__ is an open source networking platform for distributed and microservice applications. It implements the open Web Application Messaging Protocol (WAMP), is feature rich, scalable, robust and secure. Let Crossbar.io take care of the hard parts of messaging so you can focus on your app's features.

If you are new to Crossbar.io development in general you should start here at :doc:`Getting-Started`.

Contents
--------

.. toctree::
   :maxdepth: 2

   overview
   Installation
   uvlock
   Getting-Started
   programming-guide/index
   administration-guide/index
   releases
   changelog
   contributing
   OVERVIEW.md
   ai/index

--------------

*Copyright (c) typedef int GmbH. Licensed under the* `EUPL-1.2 <https://github.com/crossbario/crossbar/blob/master/LICENSE>`__.
*WAMP, Autobahn, Crossbar.io and XBR are trademarks of typedef int GmbH (Germany).*
